@@ -94,24 +94,24 @@ def read_preprocessed_applicants_list_csv(filename):
         applicant["id"] = _id("APP", 3, n)
         applicant["categories"] = categories(applicant["categories"])
         applicant["conflicts"] = conflicts(applicant["conflicts"], NO_CONFLICTS_STATEMENT)
-        applicant[FLEXIBLE] = bool(applicant[FLEXIBLE])
-        applicant[URM] = bool(applicant[URM])
-        applicant[LIM] = bool(applicant[LIM])
-        applicant[SCHOOL] = bool(applicant[SCHOOL])
+        applicant[FLEXIBLE] = bool(int(applicant[FLEXIBLE]))
+        applicant[URM] = bool(int(applicant[URM]))
+        applicant[LIM] = bool(int(applicant[LIM]))
+        applicant[SCHOOL] = bool(int(applicant[SCHOOL]))
 
         n += 1
 
     return applicants
 
-def write_matchings_list_csv(matchings, filename):
+def write_list_to_csv(lst, filename):
     """
-    Save dyad-format matchings to CSV list of matchings.
+    Save list of dict elements to file.
     """
-    headers = matchings[0].keys()
+    headers = lst[0].keys()
     with open(filename, 'w', newline='') as f:
         w = csv.DictWriter(f, headers)
         w.writeheader()
-        w.writerows(matchings)
+        w.writerows(lst)
 
 #################################################
 # APPLICANT PRIORITY METHODS
@@ -186,7 +186,9 @@ def prioritize(applicants, rank_method = asfp_rank):
         `rank_method`.
     """
     for a in applicants:
-        a["rank"] = rank_method(a)
+        a.update({
+            "rank": rank_method(a)
+        })
 
     return sorted(applicants, key = itemgetter("rank"))
 
@@ -394,11 +396,39 @@ def format_matchings(matchings, applicants, editors):
             
     return dyads
     
-def compile_unmatched_applicants(unmatched, applicants):
+def compile_unmatched(unmatched, applicants):
     """
-    Compile list of unmatched applicants after allocation.
-
-    NOTE: unmatched is a list of applicant IDs and applicants in the official
-        list of applicants
+    Compile list of unmatched applicants after allocation, using the
+      output unmatched IDs from allocate.
     """
     return [a for a in applicants if a["id"] in unmatched]
+
+def format_unmatched(unmatched_applicants):
+    """
+    Format unmatched for CSV save. Use result from compile unmatched.
+    """
+    formatted = []
+    for a in unmatched_applicants:
+        formatted.append({
+            "applicant_id": a["id"],
+            "applicant_email": a["email"],
+            "applicant_categories": ', '.join(str(c) for c in a["categories"]),
+            "applicant_rank": a["rank"]
+        })
+    return formatted
+
+def format_applicant_id_manifest(applicants):
+    """
+    Format list of identified applicants and return sorted list by
+      the identifier.
+    """
+    manifest = []
+    for a in applicants:
+        manifest.append({
+            "applicant_id": a["id"],
+            "applicant_name": a["name"],
+            "applicant_email": a["email"],
+            "applicant_categories": ", ".join(c for c in a["categories"]),
+            "applicant_rank": a["rank"]
+        })
+    return sorted(manifest, key = itemgetter("applicant_id"))
